@@ -1,11 +1,12 @@
 #' Strata at axes
-#' 
+#'
 #' \code{geom_stratum} receives a dataset of the horizontal (\code{x}) and
 #' vertical (\code{y}, \code{ymin}, \code{ymax}) positions of the strata of an
 #' alluvial diagram.
 #' It plots rectangles for these strata of a provided \code{width}.
 #' @template geom-aesthetics
-#' 
+#' @template defunct-geom-params
+#'
 
 #' @import ggplot2
 #' @family alluvial geom layers
@@ -20,7 +21,7 @@ geom_stratum <- function(mapping = NULL,
                          position = "identity",
                          show.legend = NA,
                          inherit.aes = TRUE,
-                         width = 1/3, axis_width = NULL,
+                         width = 1/3,
                          na.rm = FALSE,
                          ...) {
   layer(
@@ -32,7 +33,7 @@ geom_stratum <- function(mapping = NULL,
     show.legend = show.legend,
     inherit.aes = inherit.aes,
     params = list(
-      width = width, axis_width = axis_width,
+      width = width,
       na.rm = na.rm,
       ...
     )
@@ -44,53 +45,47 @@ geom_stratum <- function(mapping = NULL,
 #' @export
 GeomStratum <- ggproto(
   "GeomStratum", GeomRect,
-  
+
   required_aes = c("x", "y", "ymin", "ymax"),
-  
+
   default_aes = aes(size = .5, linetype = 1,
                     colour = "black", fill = "white", alpha = 1),
-  
+
   setup_params = function(data, params) {
-    
-    if (!is.null(params$axis_width)) {
-      warning("Parameter 'axis_width' is deprecated; use 'width' instead.")
-      params$width <- params$axis_width
-      params$axis_width <- NULL
-    }
-    
+
     params
   },
-  
+
   setup_data = function(data, params) {
-    
+
     transform(data,
               xmin = x - params$width / 2,
               xmax = x + params$width / 2)
   },
-  
+
   draw_panel = function(self, data, panel_params, coord,
-                        width = 1/3, axis_width = NULL) {
+                        width = 1/3) {
     # taken from GeomRect
-    
+
     strat_aes <- setdiff(
       names(data), c("x", "y", "xmin", "xmax", "ymin", "ymax")
     )
-    
+
     # construct polygon grobs
     polys <- plyr::alply(data, 1, function(row) {
-      
+
       poly <- rect_to_poly(row$xmin, row$xmax, row$ymin, row$ymax)
       aes <- as.data.frame(row[strat_aes],
                            stringsAsFactors = FALSE)[rep(1, 5), ]
-      
+
       GeomPolygon$draw_panel(cbind(poly, aes, group = 1), panel_params, coord)
     })
-    
+
     # combine polygon grobs
     grob <- do.call(grid::grobTree, polys)
     grob$name <- grid::grobName(grob, "bar")
     grob
   },
-  
+
   draw_key = draw_key_polygon
 )
