@@ -1,28 +1,27 @@
 # illustrate positioning
 ggplot(as.data.frame(Titanic),
-       aes(weight = Freq,
+       aes(y = Freq,
            axis1 = Class, axis2 = Sex, axis3 = Age,
            color = Survived)) +
   stat_stratum(geom = "errorbar") +
   geom_line(stat = "flow") +
   stat_flow(geom = "pointrange") +
   geom_text(stat = "stratum", label.strata = TRUE) +
-  scale_x_continuous(breaks = 1:3,
-                     labels = c("Class", "Sex", "Age"))
+  scale_x_discrete(limits = c("Class", "Sex", "Age"))
 
 # use of lode controls
 ggplot(as.data.frame(Titanic),
-       aes(weight = Freq,
+       aes(y = Freq,
            axis1 = Class, axis2 = Sex, axis3 = Age)) +
   geom_flow(aes(fill = Survived), aes.bind = TRUE, reverse = FALSE) +
   geom_stratum(reverse = FALSE) +
   geom_text(stat = "stratum", label.strata = TRUE, reverse = FALSE) +
-  scale_x_continuous(breaks = 1:3, labels = c("Class", "Sex", "Age"))
+  scale_x_discrete(limits = c("Class", "Sex", "Age"))
 
 data(vaccinations)
 gg <- ggplot(vaccinations,
              aes(x = survey, stratum = response, alluvium = subject,
-                 weight = freq, fill = response)) +
+                 y = freq, fill = response)) +
   geom_stratum(alpha = .5) +
   geom_text(aes(label = response), stat = "stratum")
 # rightward alluvial aesthetics for vaccine survey data
@@ -37,7 +36,7 @@ vaccinations$subgroup <- LETTERS[1:2][rbinom(
 ) + 1][vaccinations$subject]
 ggplot(vaccinations,
        aes(x = survey, stratum = response, alluvium = subject,
-           weight = freq, fill = response, label = response)) +
+           y = freq, fill = response, label = response)) +
   geom_flow(aes(alpha = subgroup)) +
   scale_alpha_discrete(range = c(1/3, 2/3)) +
   geom_stratum(alpha = .5) +
@@ -45,7 +44,7 @@ ggplot(vaccinations,
 # can even set aesthetics that vary both ways
 ggplot(vaccinations,
        aes(x = survey, stratum = response, alluvium = subject,
-           weight = freq, label = response)) +
+           y = freq, label = response)) +
   geom_flow(aes(fill = interaction(response, subgroup)), aes.bind = TRUE) +
   scale_alpha_discrete(range = c(1/3, 2/3)) +
   geom_stratum(alpha = .5) +
